# Bitti

Deney başarı ile tamamlandı.

- Süre: `%(time)s`
- Kayıt dosyası: `%(logfile)s`

Aşağıdakileri yapabilirsiniz:

[Kayıt dosyasını aç](opensesame://event.after_experiment_open_logfile){: .important-button}<br />
[Kayıt dosyasının bulunduğu klasörü aç](opensesame://event.after_experiment_open_logfile_folder){: .button}<br />
[Kayıt dosyasını dosya havuzuna at](opensesame://event.after_experiment_copy_logfile){: .button}
